
from distutils.core import setup

setup(
        name            = 'unnest.py',
        version         = '1.3.0',
        py_modules      = ['unnest'],
        author          = 'bgw',
        author_email    = 'brandonwallace@fastmail.us',
        url             = '',
        description     = 'Print items from a nested list.'
)

